==> edc_metadata_rules-0.1.17-py3-none-any.whl: edc_metadata_rules/rule_evaluator.py <==
from django.apps import apps as django_apps
from django.core.exceptions import ObjectDoesNotExist
from edc_metadata import DO_NOTHING

from .predicate import NoValueError


class RuleEvaluatorError(Exception):
    pass


class RuleEvaluatorRegisterSubjectError(Exception):
    pass


class RuleEvaluator:

    """A class to evaluate a rule.

    Sets self.result to REQUIRED, NOT_REQUIRED or None.

    Set as a class attribute on Rule.
    """

    def __init__(self, logic=None, visit=None, **kwargs):
        self._registered_subject = None
        self.logic = logic
        self.result = None
        self.visit = visit
        options = dict(
            visit=self.visit, registered_subject=self.registered_subject, **kwargs
        )
        try:
            predicate = self.logic.predicate(**options)
        except NoValueError:
            pass
        else:
            if predicate:
                if self.logic.consequence != DO_NOTHING:
                    self.result = self.logic.consequence
            else:
                if self.logic.alternative != DO_NOTHING:
                    self.result = self.logic.alternative

    @property
    def registered_subject_model(self):
        app_config = django_apps.get_app_config("edc_registration")
        return app_config.model

    @property
    def registered_subject(self):
        """Returns a registered subject model instance or raises.
        """
        if not self._registered_subject:
            try:
                self._registered_subject = self.registered_subject_model.objects.get(
                    subject_identifier=self.visit.subject_identifier
                )
            except ObjectDoesNotExist as e:
                raise RuleEvaluatorRegisterSubjectError(
                    f"Registered subject required for rule {repr(self)}. "
                    f"subject_identifier='{self.visit.subject_identifier}'. "
                    f"Got {e}."
                )
        return self._registered_subject

==> edc_metadata_rules-0.1.27-py3-none-any.whl: edc_metadata_rules/rule_evaluator.py <==
from warnings import warn

from django.apps import apps as django_apps
from django.core.exceptions import ObjectDoesNotExist
from edc_metadata import DO_NOTHING

from django.conf import settings
from .predicate import NoValueError


class RuleEvaluatorError(Exception):
    pass


class RuleEvaluatorRegisterSubjectError(Exception):
    pass


class RuleEvaluator:

    """A class to evaluate a rule.

    Sets self.result to REQUIRED, NOT_REQUIRED or None.

    Set as a class attribute on Rule.

    Ensure the model.field is registered with `site_reference_configs`.
    See `edc_reference`.
    """

    def __init__(self, logic=None, visit=None, **kwargs):
        self._registered_subject = None
        self.logic = logic
        self.result = None
        self.visit = visit
        options = dict(
            visit=self.visit, registered_subject=self.registered_subject, **kwargs
        )
        try:
            predicate = self.logic.predicate(**options)
        except NoValueError as e:
            if settings.DEBUG:
                warn(str(e))
            pass
        else:
            if predicate:
                if self.logic.consequence != DO_NOTHING:
                    self.result = self.logic.consequence
            else:
                if self.logic.alternative != DO_NOTHING:
                    self.result = self.logic.alternative

    @property
    def registered_subject_model(self):
        app_config = django_apps.get_app_config("edc_registration")
        return app_config.model

    @property
    def registered_subject(self):
        """Returns a registered subject model instance or raises.
        """
        if not self._registered_subject:
            try:
                self._registered_subject = self.registered_subject_model.objects.get(
                    subject_identifier=self.visit.subject_identifier
                )
            except ObjectDoesNotExist as e:
                raise RuleEvaluatorRegisterSubjectError(
                    f"Registered subject required for rule {repr(self)}. "
                    f"subject_identifier='{self.visit.subject_identifier}'. "
                    f"Got {e}."
                )
        return self._registered_subject
